/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
'use strict';

var _require = require('../../../transform'),
    transform = _require.transform;

var charClassToMeta = require('../char-class-to-meta-transform');

describe('char-class-to-meta', function () {
  it('replaces number ranges', function () {
    var re = transform(/[0-9$]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\d$]/');
  });
  it('replaces word ranges', function () {
    var re = transform(/[0-9a-zA-Z_$]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\w$]/');
  });
  it('replaces word ranges when regexp has i flag', function () {
    var re = transform(/[0-9a-z_$]/i, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\w$]/i');
  });
  it('replaces word ranges when regexp has i and u flags', function () {
    var re = transform("/[\\da-zA-Z_\\u017F\\u212A$]/iu", [charClassToMeta]);
    expect(re.toString()).toBe('/[\\w$]/iu');
  });
  it('whitespace ranges', function () {
    var re = transform(/[ \t\r\n\f]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\s]/');
  });
});